@@ -1,7 +1,7 @@
 use strict;
 package HTTP::BrowserDetect;
 BEGIN {
-  $HTTP::BrowserDetect::VERSION = '1.18';
+  $HTTP::BrowserDetect::VERSION = '1.19';
 }
 
 use vars qw(@ISA @EXPORT @EXPORT_OK @ALL_TESTS);
@@ -37,7 +37,7 @@ push @ALL_TESTS, qw(
     palm    audrey      iopener
     wap     blackberry  iphone
     ipod    ipad        ps3
-    psp     kindle
+    psp     kindle      webos
 );
 
 # Browsers
@@ -451,6 +451,7 @@ sub _test {
 
     $tests->{BLACKBERRY} = ( index( $ua, "blackberry" ) != -1 );
     $tests->{IPHONE}     = ( index( $ua, "iphone" ) != -1 );
+    $tests->{WEBOS}      = ( index( $ua, "webos" ) != -1 );
     $tests->{IPOD}       = ( index( $ua, "ipod" ) != -1 );
     $tests->{IPAD}       = ( index( $ua, "ipad" ) != -1 );
     $tests->{KINDLE}     = ( index( $ua, "kindle" ) != -1 );
@@ -992,7 +993,7 @@ sub device {
     my ( $self, $check ) = _self_or_default( @_ );
 
     my @devices = qw(
-        blackberry  iphone  ipod    ipad  ps3  psp
+        blackberry  iphone  ipod    ipad  ps3  psp  webos
     );
 
     foreach my $device ( @devices ) {
@@ -1013,6 +1014,7 @@ sub device_name {
         ipad => 'iPad',
         psp  => 'Sony PlayStation Portable',
         ps3  => 'Sony PlayStation 3',
+        webos => 'webOS',
     );
 
     my $device = $self->device;
@@ -1078,7 +1080,7 @@ HTTP::BrowserDetect - Determine Web browser, version, and platform from an HTTP
 
 =head1 VERSION
 
-version 1.18
+version 1.19
 
 =head1 SYNOPSIS
 
@@ -1164,7 +1166,7 @@ be in the form of an upper case 2 character code. ie: EN, DE, etc
 =head2 device()
 
 Returns the method name of the actual hardware, if it can be detected.
-Currently returns one of: blackberry, iphone, ipod or ipad  Returns UNDEF if
+Currently returns one of: blackberry, webos, iphone, ipod or ipad  Returns UNDEF if
 no hardware can be detected
 
 =head2 device_name()
@@ -1408,6 +1410,8 @@ The following methods are available, each returning a true or false value.
 
 =head3 palm
 
+=head3 webos
+
 =head3 wap
 
 =head3 psp
@@ -1575,10 +1579,24 @@ If you're able to add test cases, this will speed up the time to release your
 changes. Just edit t/useragents.yaml so that the test coverage includes any
 changes you have made.  Please contact me if you have any questions.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Lee Semel <lee@semel.net>
+
+=item *
+
+Peter Walsham
+
+=item *
 
 Olaf Alders <olaf@wundercounter.com> (current maintainer)
 
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2010 by Lee Semel.
